==> zio-aws-apigatewayv2_3-5.17.116.2-sources.jar: zio/aws/apigatewayv2/model/GetIntegrationRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetIntegrationRequest(
    apiId: __string,
    integrationId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationRequest = {
    import GetIntegrationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationRequest
      .builder()
      .apiId(__string.unwrap(apiId): java.lang.String)
      .integrationId(__string.unwrap(integrationId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetIntegrationRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetIntegrationRequest.wrap(buildAwsValue())
}
object GetIntegrationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetIntegrationRequest =
      zio.aws.apigatewayv2.model.GetIntegrationRequest(apiId, integrationId)
    def apiId: __string
    def integrationId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getIntegrationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(integrationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationRequest
  ) extends zio.aws.apigatewayv2.model.GetIntegrationRequest.ReadOnly {
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
    override val integrationId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.integrationId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationRequest
  ): zio.aws.apigatewayv2.model.GetIntegrationRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-apigatewayv2_3-6.20.47.1-sources.jar: zio/aws/apigatewayv2/model/GetIntegrationRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetIntegrationRequest(
    apiId: __string,
    integrationId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationRequest = {
    import GetIntegrationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .integrationId(integrationId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetIntegrationRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetIntegrationRequest.wrap(buildAwsValue())
}
object GetIntegrationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetIntegrationRequest =
      zio.aws.apigatewayv2.model.GetIntegrationRequest(apiId, integrationId)
    def apiId: __string
    def integrationId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getIntegrationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(integrationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationRequest
  ) extends zio.aws.apigatewayv2.model.GetIntegrationRequest.ReadOnly {
    override val apiId: __string = impl.apiId(): __string
    override val integrationId: __string = impl.integrationId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationRequest
  ): zio.aws.apigatewayv2.model.GetIntegrationRequest.ReadOnly = new Wrapper(
    impl
  )
}
